@@ -15,11 +15,11 @@ WebService::DataDog::Comment - Interface to Comment functions in DataDog's API.
 
 =head1 VERSION
 
-Version 1.0.2
+Version 1.0.3
 
 =cut
 
-our $VERSION = '1.0.2';
+our $VERSION = '1.0.3';
 
 
 =head1 SYNOPSIS
@@ -47,7 +47,7 @@ replying to an existing comment (specified with the 'related_event_id' parameter
 	$comment->create(
 		message          => $message,  # the comment text
 		handle           => $handle,   # optional - handle of the user making the comment
-		related_event_id => $event_id, # optional - the id of another comment or event to reply to
+FIXTHIS!		related_event_id => $event_id, # optional - the id of another comment or event to reply to
 	);
 	
 	Example:
@@ -68,7 +68,7 @@ Text of the comment.
 
 Handle of the user making the comment.
 
-=item * related_event_id
+=item * related_event_id   FIXTHIS!
 
 The id of another comment or event to reply to.
 
@@ -231,4 +231,4 @@ sub delete
 }
 
 
-1;
\ No newline at end of file
+1;
